@@ -141,7 +141,7 @@ xfsm_generate_client_id (SmsConn sms_conn)
       if (sms_id != NULL)
         {
           id = g_strdup (sms_id);
-          free (sms_id);
+          g_free (sms_id);
         }
     }
 
@@ -250,7 +250,7 @@ xfsm_launch_desktop_files_on_shutdown (gboolean         start_at_spi,
       return xfsm_launch_desktop_files_on_run_hook (start_at_spi, XFSM_RUN_HOOK_SWITCH_USER);
 
     default:
-      g_error ("Failed to convert shutdown type '%d' to run hook name.", shutdown_type);
+      g_critical ("Failed to convert shutdown type '%d' to run hook name.", shutdown_type);
       return FALSE;
     }
 }
@@ -407,11 +407,12 @@ xfsm_launch_desktop_files_on_run_hook (gboolean    start_at_spi,
 
           /* try to launch the command */
           xfsm_verbose ("Autostart: running command \"%s\"\n", exec);
-          if (!xfce_spawn_command_line_on_screen (gdk_screen_get_default (),
-                                                  exec,
-                                                  terminal,
-                                                  startup_notify,
-                                                  &error))
+          if (!xfce_spawn_command_line (gdk_screen_get_default (),
+                                        exec,
+                                        terminal,
+                                        startup_notify,
+                                        TRUE,
+                                        &error))
             {
               g_warning ("Unable to launch \"%s\" (specified by %s): %s", exec, files[n], error->message);
               xfsm_verbose ("Unable to launch \"%s\" (specified by %s): %s\n", exec, files[n], error->message);
