@@ -55,9 +55,6 @@
 #include <gio/gio.h>
 #include <libxfce4util/libxfce4util.h>
 #include <gtk/gtk.h>
-#ifdef HAVE_POLKIT
-#include <polkit/polkit.h>
-#endif
 
 #include <libxfsm/xfsm-util.h>
 
@@ -241,7 +238,7 @@ xfsm_shutdown_try_restart (XfsmShutdown  *shutdown,
     }
   else if (shutdown->consolekit != NULL)
     {
-      if (xfsm_consolekit_try_restart (shutdown->consolekit, error))
+      if (xfsm_consolekit_try_restart (shutdown->consolekit, NULL))
         {
           return TRUE;
         }
@@ -417,12 +414,12 @@ xfsm_shutdown_can_restart (XfsmShutdown  *shutdown,
 
   if (shutdown->systemd != NULL)
     {
-      if (xfsm_systemd_can_restart (shutdown->systemd, can_restart, error))
+      if (xfsm_systemd_can_restart (shutdown->systemd, can_restart, NULL))
         return TRUE;
     }
   else if (shutdown->consolekit != NULL)
     {
-      if (xfsm_consolekit_can_restart (shutdown->consolekit, can_restart, error))
+      if (xfsm_consolekit_can_restart (shutdown->consolekit, can_restart, NULL))
         return TRUE;
     }
 
@@ -447,12 +444,12 @@ xfsm_shutdown_can_shutdown (XfsmShutdown  *shutdown,
 
   if (shutdown->systemd != NULL)
     {
-      if (xfsm_systemd_can_shutdown (shutdown->systemd, can_shutdown, error))
+      if (xfsm_systemd_can_shutdown (shutdown->systemd, can_shutdown, NULL))
         return TRUE;
     }
   else if (shutdown->consolekit != NULL)
     {
-      if (xfsm_consolekit_can_shutdown (shutdown->consolekit, can_shutdown, error))
+      if (xfsm_consolekit_can_shutdown (shutdown->consolekit, can_shutdown, NULL))
         return TRUE;
     }
 
